@@ -9,6 +9,18 @@ as_ind <- function(i, length) {
   seq_len(length)[i]
 }
 
+#' @importFrom igraph gorder
+as_node_ind <- function(i, graph) {
+  if (!missing(i)) {
+    i <- with_graph(unfocus(graph), {{i}})
+  }
+  as_ind(i, gorder(graph))
+}
+
+compress_rank <- function(x) {
+  match(x, sort(x))
+}
+
 expect_influencer <- function(...) {
   rlang::check_installed('influenceR', ...)
 }
