@@ -1,10 +1,15 @@
 #' @importFrom dplyr group_by
 #' @export
 group_by.tbl_graph <- function(.data, ..., add = FALSE) {
+  if (is.focused_tbl_graph(.data)) {
+    cli::cli_inform('Unfocusing prior to grouping')
+    .data <- unfocus(.data)
+  }
   .register_graph_context(.data)
   d_tmp <- as_tibble(.data)
   d_tmp <- group_by(d_tmp, ..., .add = add)
-  apply_groups(.data, attributes(d_tmp))
+  .data <- set_graph_data(.data, ungroup(d_tmp))
+  apply_groups(.data, d_tmp)
 }
 #' @export
 #' @importFrom dplyr group_by
@@ -24,8 +29,8 @@ ungroup.tbl_graph <- function(x, ...) {
 #' @export
 ungroup.grouped_tbl_graph <- function(x, ...) {
   attr(x, paste0(active(x), '_group_attr')) <- NULL
-  class(x) <- class(x)[class(x) != 'grouped_tbl_graph']
-  x
+  class(x) <- setdiff(class(x), 'grouped_tbl_graph')
+  unfocus(x)
 }
 #' @export
 #' @importFrom dplyr ungroup
@@ -95,8 +100,8 @@ dplyr::group_keys
 is.grouped_tbl_graph <- function(x) {
   inherits(x, 'grouped_tbl_graph')
 }
-apply_groups <- function(graph, attributes) {
-  attr(graph, paste0(active(graph), '_group_attr')) <- attributes
+apply_groups <- function(graph, group) {
+  attr(graph, paste0(active(graph), '_group_attr')) <- attributes(group)
   if (!is.grouped_tbl_graph(graph)) {
     class(graph) <- c('grouped_tbl_graph', class(graph))
   }
