@@ -50,7 +50,6 @@
 #' @family node map functions
 #'
 #' @export
-#' @importFrom igraph gorder
 #'
 #' @examples
 #' # Accumulate values along a search
@@ -62,11 +61,11 @@
 map_bfs <- function(root, mode = 'out', unreachable = FALSE, .f, ...) {
   expect_nodes()
   graph <- .G()
-  root <- as_ind(root, gorder(graph))
+  root <- as_node_ind(root, graph)
   dot_params <- list(...)
   search_df <- bfs_df(graph, root, mode, unreachable)
   paths <- get_paths(as.integer(search_df$parent))
-  call_nodes(graph, .f, search_df, paths, dot_params)
+  call_nodes(graph, .f, search_df, paths, dot_params)[focus_ind(graph, 'nodes')]
 }
 #' @rdname map_bfs
 #' @export
@@ -133,7 +132,6 @@ map_bfs_dbl <- function(root, mode = 'out', unreachable = FALSE, .f, ...) {
 #' @family node map functions
 #'
 #' @export
-#' @importFrom igraph gorder
 #'
 #' @examples
 #' # Collect values from children
@@ -148,11 +146,11 @@ map_bfs_dbl <- function(root, mode = 'out', unreachable = FALSE, .f, ...) {
 map_bfs_back <- function(root, mode = 'out', unreachable = FALSE, .f, ...) {
   expect_nodes()
   graph <- .G()
-  root <- as_ind(root, gorder(graph))
+  root <- as_node_ind(root, graph)
   dot_params <- list(...)
   search_df <- bfs_df(graph, root, mode, unreachable)
   offspring <- get_offspring(as.integer(search_df$parent), order(search_df$rank))
-  call_nodes(graph, .f, search_df, offspring, dot_params, reverse = TRUE)
+  call_nodes(graph, .f, search_df, offspring, dot_params, reverse = TRUE)[focus_ind(graph, 'nodes')]
 }
 #' @rdname map_bfs_back
 #' @export
@@ -218,7 +216,6 @@ map_bfs_back_dbl <- function(root, mode = 'out', unreachable = FALSE, .f, ...) {
 #' @family node map functions
 #'
 #' @export
-#' @importFrom igraph gorder
 #'
 #' @examples
 #' # Add a random integer to the last value along a search
@@ -230,11 +227,11 @@ map_bfs_back_dbl <- function(root, mode = 'out', unreachable = FALSE, .f, ...) {
 map_dfs <- function(root, mode = 'out', unreachable = FALSE, .f, ...) {
   expect_nodes()
   graph <- .G()
-  root <- as_ind(root, gorder(graph))
+  root <- as_node_ind(root, graph)
   dot_params <- list(...)
   search_df <- dfs_df(graph, root, mode, unreachable)
   paths <- get_paths(as.integer(search_df$parent))
-  call_nodes(graph, .f, search_df, paths, dot_params)
+  call_nodes(graph, .f, search_df, paths, dot_params)[focus_ind(graph, 'nodes')]
 }
 #' @rdname map_dfs
 #' @export
@@ -300,7 +297,6 @@ map_dfs_dbl <- function(root, mode = 'out', unreachable = FALSE, .f, ...) {
 #' @family node map functions
 #'
 #' @export
-#' @importFrom igraph gorder
 #'
 #' @examples
 #' # Collect values from the 2 closest layers of children in a dfs search
@@ -315,11 +311,11 @@ map_dfs_dbl <- function(root, mode = 'out', unreachable = FALSE, .f, ...) {
 map_dfs_back <- function(root, mode = 'out', unreachable = FALSE, .f, ...) {
   expect_nodes()
   graph <- .G()
-  root <- as_ind(root, gorder(graph))
+  root <- as_node_ind(root, graph)
   dot_params <- list(...)
   search_df <- dfs_df(graph, root, mode, unreachable)
   offspring <- get_offspring(as.integer(search_df$parent), order(search_df$rank))
-  call_nodes(graph, .f, search_df, offspring, dot_params, reverse = TRUE)
+  call_nodes(graph, .f, search_df, offspring, dot_params, reverse = TRUE)[focus_ind(graph, 'nodes')]
 }
 #' @rdname map_dfs_back
 #' @export
@@ -388,7 +384,7 @@ map_local <- function(order = 1, mode = 'all', mindist = 0, .f, ...) {
   expect_nodes()
   graph <- .G()
   V(graph)$.central_node <- FALSE
-  res <- lapply(seq_len(gorder(graph)), function(i) {
+  res <- lapply(focus_ind(graph, 'nodes'), function(i) {
     V(graph)$.central_node[i] <- TRUE
     ego_graph <- make_ego_graph(graph, order = order, nodes = i, mode = mode, mindist = mindist)[[1]]
     .f(neighborhood = as_tbl_graph(ego_graph), graph = graph, node = i, ...)
