@@ -23,15 +23,15 @@ NULL
 
 #' @describeIn pair_measures Calculate the adhesion to the specified node. Wraps [igraph::edge_connectivity()]
 #' @export
-#' @importFrom igraph edge_connectivity gorder
+#' @importFrom igraph edge_connectivity
 #'
 #' @param nodes The other part of the node pair (the first part is the node
 #' defined by the row). Recycled if necessary.
 node_adhesion_to <- function(nodes) {
   expect_nodes()
   graph <- .G()
-  nodes <- as_ind(nodes, gorder(graph))
-  source <- seq_len(gorder(graph))
+  nodes <- as_node_ind(nodes, graph)
+  source <- focus_ind(graph, 'nodes')
   target <- rep(nodes, length.out = length(source))
   adhesion <- Map(function(s, t) {
     if (s == t) return(NA)
@@ -42,12 +42,12 @@ node_adhesion_to <- function(nodes) {
 
 #' @describeIn pair_measures Calculate the adhesion from the specified node. Wraps [igraph::edge_connectivity()]
 #' @export
-#' @importFrom igraph edge_connectivity gorder
+#' @importFrom igraph edge_connectivity
 node_adhesion_from <- function(nodes) {
   expect_nodes()
   graph <- .G()
-  nodes <- as_ind(nodes, gorder(graph))
-  target <- seq_len(gorder(graph))
+  nodes <- as_node_ind(nodes, graph)
+  target <- focus_ind(graph, 'nodes')
   source <- rep(nodes, length.out = length(target))
   adhesion <- Map(function(s, t) {
     if (s == t) return(NA)
@@ -58,43 +58,43 @@ node_adhesion_from <- function(nodes) {
 
 #' @describeIn pair_measures Calculate the cohesion to the specified node. Wraps [igraph::vertex_connectivity()]
 #' @export
-#' @importFrom igraph vertex_connectivity gorder
+#' @importFrom igraph vertex_connectivity
 node_cohesion_to <- function(nodes) {
   expect_nodes()
   graph <- .G()
-  nodes <- as_ind(nodes, gorder(graph))
-  source <- seq_len(gorder(graph))
+  nodes <- as_node_ind(nodes, graph)
+  source <- focus_ind(graph, 'nodes')
   target <- rep(nodes, length.out = length(source))
   neigh <- lapply(ego(graph, 1, source, 'out', mindist = 1), as.integer)
-  adhesion <- Map(function(s, t) {
+  adhesion <- Map(function(s, t, n) {
     if (s == t) return(NA)
-    if (t %in% neigh[[s]]) return(NA)
+    if (t %in% n) return(NA)
     vertex_connectivity(graph, source = s, target = t, checks = TRUE)
-  }, s = source, t = target)
+  }, s = source, t = target, n = neigh)
   unlist(adhesion)
 }
 
 #' @describeIn pair_measures Calculate the cohesion from the specified node. Wraps [igraph::vertex_connectivity()]
 #' @export
-#' @importFrom igraph vertex_connectivity gorder ego
+#' @importFrom igraph vertex_connectivity ego
 node_cohesion_from <- function(nodes) {
   expect_nodes()
   graph <- .G()
-  nodes <- as_ind(nodes, gorder(graph))
-  target <- seq_len(gorder(graph))
+  nodes <- as_node_ind(nodes, graph)
+  target <- focus_ind(graph, 'nodes')
   source <- rep(nodes, length.out = length(target))
   neigh <- lapply(ego(graph, 1, source, 'out', mindist = 1), as.integer)
-  adhesion <- Map(function(s, t) {
+  adhesion <- Map(function(s, t, n) {
     if (s == t) return(NA)
-    if (t %in% neigh[[s]]) return(NA)
+    if (t %in% n) return(NA)
     vertex_connectivity(graph, source = s, target = t, checks = TRUE)
-  }, s = source, t = target)
+  }, s = source, t = target, n = neigh)
   unlist(adhesion)
 }
 
 #' @describeIn pair_measures Calculate various distance metrics between node pairs. Wraps [igraph::distances()]
 #' @export
-#' @importFrom igraph distances gorder
+#' @importFrom igraph distances
 #'
 #' @param mode How should edges be followed? If `'all'` all edges are
 #' considered, if `'in'` only inbound edges are considered, and if `'out'` only
@@ -107,66 +107,60 @@ node_distance_to <- function(nodes, mode = 'out', weights = NULL, algorithm = 'a
   expect_nodes()
   graph <- .G()
   weights <- enquo(weights)
-  weights <- eval_tidy(weights, .E())
-  if (is.null(weights)) {
-    weights <- NA
-  }
-  nodes <- as_ind(nodes, gorder(graph))
-  source <- seq_len(gorder(graph))
+  weights <- eval_tidy(weights, .E()) %||% NA
+  nodes <- as_node_ind(nodes, graph)
+  source <- focus_ind(graph, 'nodes')
   target <- rep(nodes, length.out = length(source))
   target_unique <- unique(target)
   dist <- distances(graph, v = source, to = target_unique, mode = mode, weights = weights, algorithm = algorithm)
-  unlist(Map(function(s, t) {dist[s, t]}, s = source, t = match(target, target_unique)))
+  dist[cbind(source, match(target, target_unique))]
 }
 
 #' @describeIn pair_measures Calculate various distance metrics between node pairs. Wraps [igraph::distances()]
 #' @export
-#' @importFrom igraph distances gorder
+#' @importFrom igraph distances
 node_distance_from <- function(nodes, mode = 'out', weights = NULL, algorithm = 'automatic') {
   expect_nodes()
   graph <- .G()
   weights <- enquo(weights)
-  weights <- eval_tidy(weights, .E())
-  if (is.null(weights)) {
-    weights <- NA
-  }
-  nodes <- as_ind(nodes, gorder(graph))
-  target <- seq_len(gorder(graph))
+  weights <- eval_tidy(weights, .E()) %||% NA
+  nodes <- as_node_ind(nodes, graph)
+  target <- focus_ind(graph, 'nodes')
   source <- rep(nodes, length.out = length(target))
   source_unique <- unique(source)
   dist <- distances(graph, v = source_unique, to = target, mode = mode, weights = weights, algorithm = algorithm)
-  unlist(Map(function(s, t) {dist[s, t]}, s = match(source, source_unique), t = target))
+  dist[cbind(match(source, source_unique), target)]
 }
 
 #' @describeIn pair_measures Calculate node pair cocitation count. Wraps [igraph::cocitation()]
 #' @export
-#' @importFrom igraph cocitation gorder
+#' @importFrom igraph cocitation
 node_cocitation_with <- function(nodes) {
   expect_nodes()
   graph <- .G()
-  nodes <- as_ind(nodes, gorder(graph))
-  source <- seq_len(gorder(graph))
+  nodes <- as_node_ind(nodes, graph)
+  source <- focus_ind(graph, 'nodes')
   target <- rep(nodes, length.out = length(source))
   cocite <- cocitation(graph)
-  unlist(Map(function(s, t) {cocite[s, t]}, s = source, t = target))
+  cocite[cbind(source, target)]
 }
 
 #' @describeIn pair_measures Calculate node pair bibliographic coupling. Wraps [igraph::bibcoupling()]
 #' @export
-#' @importFrom igraph bibcoupling gorder
+#' @importFrom igraph bibcoupling
 node_bibcoupling_with <- function(nodes) {
   expect_nodes()
   graph <- .G()
-  nodes <- as_ind(nodes, gorder(graph))
-  source <- seq_len(gorder(graph))
+  nodes <- as_node_ind(nodes, graph)
+  source <- focus_ind(graph, 'nodes')
   target <- rep(nodes, length.out = length(source))
   bibc <- bibcoupling(graph)
-  unlist(Map(function(s, t) {bibc[s, t]}, s = source, t = target))
+  bibc[cbind(source, target)]
 }
 
 #' @describeIn pair_measures Calculate various node pair similarity measures. Wraps [igraph::similarity()]
 #' @export
-#' @importFrom igraph similarity gorder
+#' @importFrom igraph similarity
 #'
 #' @param loops Should loop edges be considered
 #' @param method The similarity measure to calculate. Possible values are:
@@ -174,16 +168,16 @@ node_bibcoupling_with <- function(nodes) {
 node_similarity_with <- function(nodes, mode = 'out', loops = FALSE, method = 'jaccard') {
   expect_nodes()
   graph <- .G()
-  nodes <- as_ind(nodes, gorder(graph))
-  source <- seq_len(gorder(graph))
+  nodes <- as_node_ind(nodes, graph)
+  source <- focus_ind(graph, 'nodes')
   target <- rep(nodes, length.out = length(source))
   sim <- similarity(graph, mode = mode, loops = loops, method = method)
-  unlist(Map(function(s, t) {sim[s, t]}, s = source, t = target))
+  sim[cbind(source, target)]
 }
 
 #' @describeIn pair_measures Calculate the maximum flow to a node. Wraps [igraph::max_flow()]
 #' @export
-#' @importFrom igraph max_flow gorder
+#' @importFrom igraph max_flow
 #'
 #' @param capacity The edge capacity to use
 node_max_flow_to <- function(nodes, capacity = NULL) {
@@ -191,8 +185,8 @@ node_max_flow_to <- function(nodes, capacity = NULL) {
   graph <- .G()
   capacity <- enquo(capacity)
   capacity <- eval_tidy(capacity, .E())
-  nodes <- as_ind(nodes, gorder(graph))
-  source <- seq_len(gorder(graph))
+  nodes <- as_node_ind(nodes, graph)
+  source <- focus_ind(graph, 'nodes')
   target <- rep(nodes, length.out = length(source))
   flow <- Map(function(s, t) {
     if (s == t) return(NA)
@@ -203,14 +197,14 @@ node_max_flow_to <- function(nodes, capacity = NULL) {
 
 #' @describeIn pair_measures Calculate the maximum flow from a node. Wraps [igraph::max_flow()]
 #' @export
-#' @importFrom igraph max_flow gorder
+#' @importFrom igraph max_flow
 node_max_flow_from <- function(nodes, capacity = NULL) {
   expect_nodes()
   graph <- .G()
   capacity <- enquo(capacity)
   capacity <- eval_tidy(capacity, .E())
-  nodes <- as_ind(nodes, gorder(graph))
-  target <- seq_len(gorder(graph))
+  nodes <- as_node_ind(nodes, graph)
+  target <- focus_ind(graph, 'nodes')
   source <- rep(nodes, length.out = length(target))
   flow <- Map(function(s, t) {
     if (s == t) return(NA)
