@@ -1,5 +1,3 @@
-context("context")
-
 test_that("graphs get added and stacked in the context", {
   context <- ContextBuilder$new()
   expect_false(context$alive())
@@ -19,3 +17,5 @@ test_that("graphs get added and stacked in the context", {
   context$clear()
   expect_false(context$alive())
 })
+
+test_empty_context()
