@@ -1,7 +1,7 @@
 test_that("random_walk_rank returns correct data", {
   set.seed(1)
   node_walk <- create_notable('zachary') |>
-    mutate(walk_rank = random_walk_rank(30, 5)) |>
+    mutate(walk_rank = random_walk_rank(29, 5)) |>
     pull(walk_rank)
 
   edge_walk <- create_notable('zachary') |>
@@ -13,9 +13,9 @@ test_that("random_walk_rank returns correct data", {
   expect_length(edge_walk, 78)
   expect_type(node_walk, 'list')
   expect_type(edge_walk, 'list')
-  expect_equal(node_walk[[5]], c(1, 12))
-  expect_equal(node_walk[[2]], integer())
+  expect_equal(node_walk[[5]], c(1, 5, 7))
+  expect_equal(node_walk[[3]], integer())
   expect_equal(edge_walk[[1]], integer())
   skip_on_cran()
-  expect_equal(edge_walk[[36]], 1:4)
+  expect_equal(edge_walk[[4]], c(1, 18))
 })
